#ifndef SENSOR_PARAMETER_H
#define SENSOR_PARAMETER_H

/*!
  \file
  \brief ZTp[^Ǘ

  \author Satofumi KAMIMURA

  $Id$
*/

#include <string>


namespace beego {
  /*!
    \brief ZTp[^̕ێNX
  */
  class SensorParameter {
  public:
    enum {
      MODL = 0,			//!< ZT^
      DMIN,			//!< ŏv\ [mm]
      DMAX,			//!< őv\ [mm]
      ARES,			//!< px\(360x̕)
      AMIN,			//!< ŏv\l
      AMAX,			//!< őv\l
      AFRT,			//!< ʕl
      SCAN,			//!< Wpx
    };
    std::string model;
    long distance_min;
    long distance_max;
    int area_total;
    int area_min;
    int area_max;
    int area_front;
    int scan_rpm;

    SensorParameter(void)
      : model(""), distance_min(0), distance_max(0), area_total(0),
	area_min(0), area_max(0), area_front(0), scan_rpm(600) {
    }
  };
};

#endif /* !SENSOR_PARAMETER_H */
